require 'test/unit'
require 'test/DataDictionaryTestCase'
require 'test/DictionaryTestCase'
require 'test/FieldBaseTestCase'
require 'test/SessionSettingsTestCase'
require 'test/MessageTestCase'